@@ -118,13 +118,12 @@ class Workflow:
             f.write(self._workflow_imports)
             f.write("# Workflow\n")
             f.write(self._workflow_instantiation)
-            f.write("# Nodes\n")
+            f.write("    # Nodes\n")
             for n in self.nodes:
                 operator = f"{n.task.__name__.lower()}_operator"
-                f.write(f"{operator} = {n.operator_definition}")
-                f.write(f"d.add_task({operator})\n")
+                f.write(f"    {operator} = {n.operator_definition}")
                 f.write("\n")
-            f.write("# Edges\n")
+            f.write("    # Edges\n")
             f.write(self._workflow_edges)
             f.write("\n")
         return workflow_py
@@ -147,14 +146,14 @@ class Workflow:
 
     @property
     def _workflow_instantiation(self) -> str:
-        return f"d = {self._dag_definition}\n"
+        return f"with {self._dag_definition} as d:\n    pass\n"
 
     @property
     def _workflow_edges(self) -> str:
         edges = []
         for n in self.nodes:
             for upstream, downstream in n.dependencies:
-                edges.append(f"d.set_dependency('{upstream}', '{downstream}')")
+                edges.append(f"    d.set_dependency('{upstream}', '{downstream}')")
         return "\n".join(edges)
 
     def __repr__(self):
